@@ -18,7 +18,7 @@
 	Copyright (C) 2011 - 2015, Simon Hampe <simon.hampe@googlemail.com>
 
 	---
-	Copyright (c) 2016-2020
+	Copyright (c) 2016-2024
 	Ewgenij Gawrilow, Michael Joswig, and the polymake team
 	Technische Universität Berlin, Germany
 	https://polymake.org
@@ -43,8 +43,7 @@
 #include "polymake/tropical/linear_algebra_tools.h"
 #include "polymake/tropical/polynomial_tools.h"
 
-#ifndef POLYMAKE_ATINT_RATIONAL_FUNCTION_H
-#define POLYMAKE_ATINT_RATIONAL_FUNCTION_H
+#pragma once
 
 namespace polymake { namespace tropical {
 
@@ -105,4 +104,3 @@ BigObject computePolynomialDomain(const Polynomial<TropicalNumber<Addition>>& p)
 
 } }
 
-#endif
