@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2024
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,12 +15,11 @@
 --------------------------------------------------------------------------------
 */
 
+#pragma once
 /** @file color.h
     @brief Implementation of pm::RGB and pm::HSV classes
  */
 
-#ifndef POLYMAKE_COLOR_H
-#define POLYMAKE_COLOR_H
 
 #include "polymake/GenericStruct.h"
 #include "polymake/GenericIO.h"
@@ -40,9 +40,9 @@ class HSV;
 */
 class RGB : public GenericStruct<RGB> {
 public:
-   DeclSTRUCT( DeclFIELD(red,double)
-               DeclFIELD(green,double)
-               DeclFIELD(blue,double) );
+   DeclSTRUCT( DeclFIELD(red, double)
+               DeclFIELD(green, double)
+               DeclFIELD(blue, double) );
 protected:
    void verify() const;
    void scale_and_verify();
@@ -54,8 +54,8 @@ public:
    /// constructor from individual color channels
    RGB(double r, double g, double b) : red(r), green(g), blue(b) { verify(); }
 
-   /// ... variant for int parameters
-   RGB(int r, int g, int b) : red(r), green(g), blue(b) { scale_and_verify(); }
+   /// ... variant for integer parameters
+   RGB(Int r, Int g, Int b) : red(double(r)), green(double(g)), blue(double(b)) { scale_and_verify(); }
 
    /// converts from HSV representation
    RGB(const HSV&);
@@ -85,9 +85,9 @@ struct redirect_object_traits<RGB>
 */
 class HSV : public GenericStruct<HSV> {
 public:
-   DeclSTRUCT( DeclFIELD(hue,double)
-               DeclFIELD(saturation,double)
-               DeclFIELD(value,double) );
+   DeclSTRUCT( DeclFIELD(hue, double)
+               DeclFIELD(saturation, double)
+               DeclFIELD(value, double) );
 protected:
    void verify() const;
 public:
@@ -108,7 +108,6 @@ namespace polymake {
    using pm::HSV;
 }
 
-#endif // POLYMAKE_COLOR_H
 
 // Local Variables:
 // mode:C++
