@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2023
+/* Copyright (c) 1997-2024
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -34,7 +34,11 @@ class allocator : public PM_ALLOCATOR_BASE<char> {
 public:
    void* allocate(std::size_t n)
    {
+#if __cplusplus < 201703L
       return base_t::allocate(n, nullptr);
+#else
+      return base_t::allocate(n);
+#endif
    }
    void deallocate(void* p, std::size_t n)
    {
