@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2024
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
    --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_TYPE_UTILS_H
-#define POLYMAKE_TYPE_UTILS_H
+#pragma once
 
 #include "polymake/meta_list.h"
 #include <cstddef>
@@ -702,7 +701,6 @@ std::string legible_typename()
 
 }
 
-#endif // POLYMAKE_TYPE_UTILS_H
 
 // Local Variables:
 // mode:C++
