@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2020
+#  Copyright (c) 1997-2024
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -661,6 +661,8 @@ sub deserialize {
         or croak( "no polymake data items in deserialized data" );
       my $main_version = eval("v".$ns_data->[1]);
       my $version_bump = $VersionNumber gt $main_version;
+      warn_print("loading a file from a future polymake version ", $ns_data->[1], " is unsupported and might crash polymake")
+         if ($VersionNumber lt $main_version);
 
       if (defined(my $top_ext = $src->{_ext})) {
          $mandatory[$_] = true for @$top_ext;
@@ -1114,9 +1116,8 @@ sub deserialize {
          $type = $app->eval_type($type) // croak( "invalid type $type for property $name" );
       }
       if ($prop_attrs && $prop_attrs->{attachment}) {
-         if (defined($type) && instanceof BigObjectType($type)) {
-            # resolve conflict between small and big object types with coinciding names
-            $type = $app->eval_type("props::".$prop_attrs->{_type}) // croak( "invalid type $prop_attrs->{_type} of attachment $name" );
+         if (instanceof BigObjectType($type)) {
+            croak( "invalid type $prop_attrs->{_type} of attachment $name" );
          }
          if (defined(my $construct_args = $prop_attrs->{construct})) {
             defined($type)
